import { core, flags, SfdxCommand } from "@salesforce/command";
import { SFPowerkit } from "../../../sfpowerkit";
import PoolFetchImpl from "../../../impl/pool/scratchorg/poolFetchImpl";
// Initialize Messages with the current plugin directory
core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = core.Messages.loadMessages("sfpowerkit", "scratchorg_poolFetch");
export default class Fetch extends SfdxCommand {
    async run() {
        SFPowerkit.setLogLevel("DEBUG", false);
        await this.hubOrg.refreshAuth();
        const hubConn = this.hubOrg.getConnection();
        this.flags.apiversion =
            this.flags.apiversion || (await hubConn.retrieveMaxApiVersion());
        let fetchImpl = new PoolFetchImpl(this.hubOrg, this.flags.apiversion, this.flags.tag, this.flags.mypool);
        let result = await fetchImpl.execute();
        if (!this.flags.json) {
            this.ux.log(`======== Scratch org details ========`);
            let list = [];
            for (let [key, value] of Object.entries(result)) {
                if (value) {
                    list.push({ key: key, value: value });
                }
            }
            this.ux.table(list, ["key", "value"]);
        }
        return JSON.stringify(result);
    }
}
Fetch.description = messages.getMessage("commandDescription");
Fetch.requiresDevhubUsername = true;
Fetch.examples = [
    `$ sfdx sfpowerkit:pool:fetch -t core `,
    `$ sfdx sfpowerkit:pool:fetch -t core -v devhub`,
    `$ sfdx sfpowerkit:pool:fetch -t core -v devhub -m`
];
Fetch.flagsConfig = {
    tag: flags.string({
        char: "t",
        description: messages.getMessage("tagDescription"),
        required: true
    }),
    mypool: flags.boolean({
        char: "m",
        description: messages.getMessage("mypoolDescription"),
        required: false
    })
};
//# sourceMappingURL=fetch.js.map