import * as _ from "lodash";
import { METADATA_INFO } from "../metadataInfo";
import BaseMetadataRetriever from "./baseMetadataRetriever";
import MetadataFiles from "../metadataFiles";
const QUERY = "Select Id, Name, NameSpacePrefix From ApexClass ";
export default class ApexClassRetriever extends BaseMetadataRetriever {
    constructor(org) {
        super(org, true);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!ApexClassRetriever.instance) {
            ApexClassRetriever.instance = new ApexClassRetriever(org);
        }
        return ApexClassRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            super.setQuery(QUERY);
            let classes = await super.getObjects();
            for (let i = 0; i < classes.length; i++) {
                let cls = classes[i];
                if (!_.isNil(cls.NamespacePrefix)) {
                    cls.FullName = `${cls.NamespacePrefix}__${cls.Name}`;
                }
                else {
                    cls.FullName = cls.Name;
                }
            }
            this.data = classes;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async getClasses() {
        return await this.getObjects();
    }
    async classExists(cls) {
        let found = false;
        //Look first in project files
        if (!_.isNil(METADATA_INFO.ApexClass.components)) {
            found = METADATA_INFO.ApexClass.components.includes(cls);
        }
        if (!found && !MetadataFiles.sourceOnly) {
            //not found, check on the org
            let classes = await this.getClasses();
            let foundCls = classes.find(aCls => {
                return aCls.FullName === cls;
            });
            found = !_.isNil(foundCls);
        }
        return found;
    }
}
//# sourceMappingURL=apexClassRetriever.js.map