import * as _ from "lodash";
import { METADATA_INFO } from "../metadataInfo";
import BaseMetadataRetriever from "./baseMetadataRetriever";
import MetadataFiles from "../metadataFiles";
const QUERY = "Select Id, Name, NameSpacePrefix From ApexPage";
export default class ApexPageRetriever extends BaseMetadataRetriever {
    constructor(org) {
        super(org, true);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!ApexPageRetriever.instance) {
            ApexPageRetriever.instance = new ApexPageRetriever(org);
        }
        return ApexPageRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            super.setQuery(QUERY);
            let pages = await super.getObjects();
            for (let i = 0; i < pages.length; i++) {
                let page = pages[i];
                if (!_.isNil(page.NamespacePrefix)) {
                    page.FullName = `${page.NamespacePrefix}__${page.Name}`;
                }
                else {
                    page.FullName = page.Name;
                }
            }
            this.data = pages;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async getPages() {
        return await this.getObjects();
    }
    async pageExists(page) {
        let found = false;
        //Look first in project files
        if (!_.isNil(METADATA_INFO.ApexPage.components)) {
            found = METADATA_INFO.ApexPage.components.includes(page);
        }
        if (!found && !MetadataFiles.sourceOnly) {
            //not found, check on the org
            let pages = await this.getPages();
            let foundPage = pages.find(p => {
                return p.FullName === page;
            });
            found = !_.isNil(foundPage);
        }
        return found;
    }
}
//# sourceMappingURL=apexPageRetriever.js.map