import * as _ from "lodash";
import BaseMetadataRetriever from "./baseMetadataRetriever";
import EntityDefinitionRetriever from "./entityDefinitionRetriever";
import { METADATA_INFO } from "../metadataInfo";
import MetadataFiles from "../metadataFiles";
const QUERY = "SELECT Id, QualifiedApiName, EntityDefinitionId, DeveloperName, NamespacePrefix FROM FieldDefinition";
export default class FieldRetriever extends BaseMetadataRetriever {
    constructor(org) {
        super(org, true);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!FieldRetriever.instance) {
            FieldRetriever.instance = new FieldRetriever(org);
        }
        return FieldRetriever.instance;
    }
    async getObjects() {
        let fieldsToReturn = [];
        if (!this.data && !this.dataLoaded) {
            let entityDefinitionUtils = EntityDefinitionRetriever.getInstance(this.org);
            let objects = await entityDefinitionUtils.getObjectForPermission();
            this.data = {};
            for (let i = 0; i < objects.length; i++) {
                let objectName = objects[i];
                super.setQuery(QUERY +
                    " WHERE EntityDefinition.QualifiedApiName ='" +
                    objectName +
                    "'");
                let fields = await super.getObjects();
                fields = fields.map(field => {
                    field.SobjectType = objectName;
                    field.FullName = objectName + "." + field.QualifiedApiName;
                    return field;
                });
                this.data[objectName] = fields;
                fieldsToReturn.push(...fields);
            }
            this.dataLoaded = true;
        }
        else {
            if (this.data) {
                Object.keys(this.data).forEach(key => {
                    fieldsToReturn.push(...this.data[key]);
                });
            }
        }
        return fieldsToReturn;
    }
    async getFields() {
        return await this.getObjects();
    }
    async getFieldsByObjectName(objectName) {
        if (!this.data) {
            await this.getObjects();
        }
        if (!this.data[objectName]) {
            let fields = [];
            super.setQuery(QUERY + " WHERE EntityDefinition.QualifiedApiName ='" + objectName + "'");
            fields = await super.getObjects();
            fields = fields.map(field => {
                field.SobjectType = objectName;
                field.FullName = objectName + "." + field.QualifiedApiName;
                return field;
            });
            this.data[objectName] = fields;
        }
        return this.data[objectName];
    }
    async fieldExist(fullName) {
        let found = false;
        let fieldParts = fullName.split(".");
        if (fieldParts.length !== 2) {
            return false;
        }
        //Look first in project files
        if (!_.isNil(METADATA_INFO.CustomField.components)) {
            found = METADATA_INFO.CustomField.components.includes(fullName);
        }
        if (!found && !MetadataFiles.sourceOnly) {
            //not found, check on the org
            let objectName = fieldParts[0];
            let fieldDefinitions = await this.getFieldsByObjectName(objectName);
            let field = fieldDefinitions.find(field => field.FullName === fullName);
            found = field !== undefined;
        }
        return found;
    }
}
//# sourceMappingURL=fieldRetriever.js.map